#!/bin/sh

. /usr/syno/sbin/synovrcap_util.sh

AddSchedule()
{
	if [ "x$(grep "${0##*/}" /etc/crontab)" != "x" ]; then
		exit 0
	fi
	local tmp_crontab=/tmp/crontab.$$
	local shell_crontab=/usr/syno/sbin/${0##*/}
	touch $tmp_crontab
	cat /etc/crontab | grep -v "${0##*/}" > $tmp_crontab
	RANDOM=$$
	echo -e "$(($RANDOM%60))\t$(($RANDOM%24))\t*\t*\t*\troot\t${shell_crontab} upgrade-package" >> $tmp_crontab
	mv $tmp_crontab /etc/crontab
	exit 0
}

RemoveSchedule()
{
	local tmp_crontab=/tmp/crontab.$$
	touch $tmp_crontab
	cat /etc/crontab | grep -v "${0##*/}" > $tmp_crontab
	mv $tmp_crontab /etc/crontab
}

RollbackUpdateServer()
{
	local rss_server="http://update.synology.com/autoupdate/genRSS.php"
	local rss_server_ssl="https://update.synology.com/autoupdate/genRSS.php"
	local small_info_path="https://update.synology.com/smallupdate"

	local synoinfos="/etc/synoinfo.conf /etc.defaults/synoinfo.conf"

	for synoinfo in ${synoinfos}; do
		/usr/syno/bin/synosetkeyvalue "${synoinfo}" rss_server ${rss_server}
		/usr/syno/bin/synosetkeyvalue "${synoinfo}" rss_server_ssl ${rss_server_ssl}
		/usr/syno/bin/synosetkeyvalue "${synoinfo}" small_info_path ${small_info_path}
	done
}

ResetPackage()
{
	local package=$1

	RemoveSchedule
	RollbackUpdateServer
	synopkg uninstall "${package}"
	/bin/rm -f /etc/init/synovrcap_update.conf
	/bin/rm -f ${ALL_WHITELIST_PATH}
}

UninstallNotValidPackage()
{
	. /etc.defaults/VERSION #majorversion minorversion buildnumber

	# synoinfo
	local unique=$(synogetkeyvalue /etc/synoinfo.conf unique)
	local codepage=$(synogetkeyvalue /etc/synoinfo.conf codepage)

	local package="VRCap"
	local version="${majorversion}/${minorversion}/${buildnumber}"
	local platform=$(echo "${unique}" | cut -d"_" -f 2)
	local pkg_server="https://pkgautoupdate.synology.com"
	local valid_server=$(GetValidServer)
	local serial=$(cat /proc/sys/kernel/syno_serial)

	# Not VRC and not in whitelist => uninstall package
	if ! IsWhiteListedDevice "${serial}" &&
			[ "x$(echo "${serial}" | cut -c5-7)" != "xVRC" ] &&
			[ "x$(echo "${serial}" | cut -c5-7)" != "xVRW" ]; then
		echo "Not VRCap device"
		ResetPackage "${package}"
		exit 0
	fi

	# Never expired
	if IsNeverExpiredListedDevice "${serial}"; then
		return
	fi

	# Not valid(expired) => uninstall package
	local valid=$(curl -X POST --data "sn=${serial}" -H "Content-Type: application/x-www-form-urlencoded" "${valid_server}" | jq .[].valid)
	if [ "x${valid}" == "xfalse" ]; then
		echo "Not valid. Uninstall synovrcap"
		ResetPackage "${package}"
		exit 0
	elif [ "x${valid}" != "xtrue" ]; then
		exit 0
	fi
}

UpgradePackage()
{
	. /etc.defaults/VERSION #majorversion minorversion buildnumber

	# synoinfo
	local unique=$(synogetkeyvalue /etc/synoinfo.conf unique)
	local codepage=$(synogetkeyvalue /etc/synoinfo.conf codepage)

	local package="VRCap"
	local version="${majorversion}/${minorversion}/${buildnumber}"
	local platform=$(echo "${unique}" | cut -d"_" -f 2)
	local pkg_server="https://pkgautoupdate.synology.com"

	local url="${pkg_server}/getUpdate/${package}/${version}/${platform}/stable/${unique}/${codepage}/JP"
	local spk_info=$(curl -s "${url}")
	local latest_version=$(echo "${spk_info}" | jq -r ".package.version" | cut -d"-" -f 2)
	local current_version=$(synopkg version VRCap | cut -d"-" -f 2)
	local serial

	serial=$(cat /proc/sys/kernel/syno_serial)

	if [ "x${latest_version}" == "xnull" ]; then
		echo "cannot get the latest version"
		exit 0
	fi

	if [ -z "$current_version" ]; then
		echo "Installing package..."
		local link=$(echo "${spk_info}" | jq -r ".package.link")
		echo "${link}"
		local spk_name=/tmp/$(basename "${link}")
		curl "${link}" --output "${spk_name}"
		synopkg install "${spk_name}"
		/bin/rm "${spk_name}"
	elif [ "${latest_version}" -gt "${current_version}" ]; then
		if ! IsNeverExpiredListedDevice "${serial}"; then
			count=1
			count_file="/var/packages/VRCap/etc/count.txt"
			if [ ! -f "${count_file}" ]; then
				echo 1 > "${count_file}"
			else
				count=$(cat "${count_file}")
				count=$((count+1))
				echo $count > "${count_file}"
			fi

			if [ $count -le 7 ]; then
				exit 0
			fi
			rm "${count_file}"
		fi
		echo "Upgrading package..."
		local link=$(echo "${spk_info}" | jq -r ".package.link")
		echo "${link}"
		local spk_name=/tmp/$(basename "${link}")
		curl "${link}" --output "${spk_name}"
		synopkg install "${spk_name}"
		/bin/rm "${spk_name}"
	else
		echo "Package is up-to-date."
	fi
}

case "$1" in
	"add-schedule")
		AddSchedule
		;;
	"remove-schedule")
		RemoveSchedule
		;;
	"upgrade-package")
		UninstallNotValidPackage
		UpgradePackage
		;;
	*)
		echo $"Usage: ${0##*/} {add-schedule|remove-schedule|upgrade-package}"
		exit 2
		;;
esac
