#!/bin/sh

PACKAGE_WHITELIST_PATH="/var/packages/VRCap/conf/serial"
PACKAGE_NEVER_EXPIRED_PATH="/var/packages/VRCap/conf/never_expired_serial"
SYSTEM_WHITELIST_PATH="/usr/syno/etc.defaults/vrcap_serial"
ALL_WHITELIST_PATH="/usr/syno/etc/vrcap_serial ${SYSTEM_WHITELIST_PATH}"
VRCAP_CONFIG="/var/packages/VRCap/conf/config.ini"
SYSTEM_VRCAP_CONFIG="/usr/syno/etc.defaults/vrcap_config.ini"

IsWhiteListedDevice()
{
	local serial=$1
	local whitelist=${PACKAGE_WHITELIST_PATH}

	if [ ! -f "${whitelist}" ];then
		whitelist=${SYSTEM_WHITELIST_PATH}
		if [ ! -f "${whitelist}" ];then
			# 1 = false
			return 1
		fi
	fi

	while read line
	do
		sn=${line}
		case $sn in "${serial}")
			# 0 = true
			return 0
			;;
		esac
	done < ${whitelist}

	# 1 = false
	return 1
}

IsNeverExpiredListedDevice()
{
	local serial=$1
	local whitelist=${PACKAGE_NEVER_EXPIRED_PATH}

	if [ ! -f "${whitelist}" ];then
		# 1 = false
		return 1
	fi

	while read line
	do
		sn=${line}
		case $sn in "${serial}")
			# 0 = true
			return 0
			;;
		esac
	done < ${whitelist}

	# 1 = false
	return 1
}

GetValidServer()
{
	local validServer=$(synogetkeyvalue ${VRCAP_CONFIG} valid_server)

	if [ "x${validServer}" = "x" ]; then
		validServer=$(synogetkeyvalue ${SYSTEM_VRCAP_CONFIG} valid_server)
	fi

	echo "${validServer}"
}

GetVrcapUSBMountPoint()
{
	for item in /sys/block/sd*; do
		local MAN_DEV=$(basename "${item}");
		local MAN_PART=""
		if [ ! -d "/sys/block/${MAN_DEV}" ]; then
			continue;
		elif [ -d "/sys/block/${MAN_DEV}/${MAN_DEV}1" ]; then
			# try first part
			MAN_PART="${MAN_DEV}1"
		else
			# try entire disk
			MAN_PART=""
		fi

		# check if VRCap devices
		local sz=$(cat "/sys/block/${MAN_DEV}/${MAN_PART}/size")
		if [ 2097252 -ne "$sz" ]; then
			continue;
		fi
		local mpoint=$(df | grep ${MAN_PART} | awk '{print $6}')
		if [ ! -f "${mpoint}/.Vrcap" ]; then
			continue;
		fi
		echo "${mpoint}"
		return
	done

	echo ""
}

InitAllLightsTrigger()
{
	model=$(synogetkeyvalue /etc.defaults/synoinfo.conf unique)
	if [ "x${model}" = "xsynology_dakota_mr2200ac" ]; then
		echo default-on > /sys/class/leds/green/trigger
		echo default-on > /sys/class/leds/middle/trigger
		echo default-on > /sys/class/leds/high/trigger
		echo default-on > /sys/class/leds/red/trigger
		echo default-on > /sys/class/leds/blue/trigger
		echo none > /sys/class/leds/green/trigger
		echo none > /sys/class/leds/middle/trigger
		echo none > /sys/class/leds/high/trigger
		echo none > /sys/class/leds/red/trigger
		echo none > /sys/class/leds/blue/trigger
	else
		echo 0 > /sys/class/leds/green\:status/brightness
		echo 0 > /sys/class/leds/orange\:status/brightness
		echo none > /sys/class/leds/orange\:status/trigger
		echo none > /sys/class/leds/green\:status/trigger
	fi
}

GreenLightsOn()
{
	model=$(synogetkeyvalue /etc.defaults/synoinfo.conf unique)
	if [ "x${model}" = "xsynology_dakota_mr2200ac" ]; then
		echo 0 > /sys/class/leds/blue/brightness
		echo 255 > /sys/class/leds/green/brightness
		echo 255 > /sys/class/leds/middle/brightness
		echo 255 > /sys/class/leds/high/brightness
	else
		echo none > /sys/class/leds/green\:status/trigger
		echo 0 > /sys/class/leds/orange\:status/brightness
		echo 0 > /sys/class/leds/green\:status/brightness
		echo 255 > /sys/class/leds/green\:status/brightness
	fi
}

RedLightOn()
{
	model=$(synogetkeyvalue /etc.defaults/synoinfo.conf unique)
	if [ "x${model}" = "xsynology_dakota_mr2200ac" ]; then
		echo 0 > /sys/class/leds/green/brightness
		echo 255 > /sys/class/leds/red/brightness
	else
		echo none > /sys/class/leds/orange\:status/trigger
		echo 0 > /sys/class/leds/green\:status/brightness
		echo 0 > /sys/class/leds/orange\:status/brightness
		echo 255 > /sys/class/leds/orange\:status/brightness
	fi
}
